@@ -1,5 +1,5 @@
 =begin
-= GrADS_Gridded  -- a class for GrADS gridded datasets
+= NumRu::GrADS_Gridded  -- a class for GrADS gridded datasets
 
 by T Horinouchi and R Mizuta
 
@@ -442,14 +442,15 @@ EOS
 
   def get(name, level, time)
     if ( @options["template"] )
-      time_a = get_dim(@dimensions[3])     # julian day for 12UTC
-      time_d = Date.new1(time_a[time]-0.5) # precise julian day for 00UTC
+      time_a = get_dim(@dimensions[3]) # julian day(integer) + time of day
+#      time_d = Date.new1(time_a[time]-0.5) # precise julian day for 00UTC
+      time_d = Date.new1(time_a[time].floor) # julian day(integer)
       init_year = time_d.year
       init_month = time_d.month
       init_day = time_d.day
       @dset_r = @dset.dup
       if ( @dset_r =~ /%y2/ || @dset_r =~ /%y4/)
-        init_month = 1  if !( @dset_r =~ /%m2/ )
+        init_month = 1  if (!( @dset_r =~ /%m2/ )&&!( @dset_r =~ /%m1/ ))
         init_day = 1    if !( @dset_r =~ /%d2/ )
         @dset_r.gsub!( /%y2/, sprintf("%02d",time_d.year%100) )
         @dset_r.gsub!( /%y4/, sprintf("%04d",time_d.year) )
@@ -458,6 +459,10 @@ EOS
         init_day = 1    if !( @dset_r =~ /%d2/ )
         @dset_r.gsub!( /%m2/, sprintf("%02d",time_d.month) )
       end
+      if ( @dset_r =~ /%m1/ )
+        init_day = 1    if !( @dset_r =~ /%d2/ )
+        @dset_r.gsub!( /%m1/, sprintf("%d",time_d.month) )
+      end
       if ( @dset_r =~ /%d2/ )
 #        time_d...
         @dset_r.gsub!( /%d2/, sprintf("%02d",time_d.day) )
@@ -489,7 +494,7 @@ EOS
     ary
   end
 
-  attr_accessor (:title, :undef, :dset, :dimensions, :variables)
+  attr_accessor(:title, :undef, :dset, :dimensions, :variables)
   def ctlfilename
     @ctlfile.path
   end
@@ -659,8 +664,10 @@ EOS
               start,increment= spec.split
               julian_day = parse_starttime(start)
               dim[:start] = julian_day
-              dim[:start_units] = 'days since '+Date.new1(0.0).to_s
+              dim[:start_units] = 'days since '+Date.new1(0.0).to_s+' 00UTC'
               dim[:increment],dim[:increment_units] = parse_timeincrement(increment)
+#              dim[:units] = dim[:increment_units]
+              dim[:units] = dim[:start_units]
             else
               raise "invalid dimension flag(only LINEAR is available for time)"
             end
@@ -679,7 +686,7 @@ EOS
             break
           else
 #            vline =~ /^\s*(\S+)\s+(\S+)\s+(\S+)\s+(\S+.*?)\s*$/
-            vline =~ /^\s*(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+.*?)\s*$/
+            vline =~ /^\s*(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s*(\S+.*?)\s*$/
             if( !($1 && $2 && $3 && $4) )
               raise "Something is wrong with this line: "+vline
             end
@@ -907,7 +914,7 @@ class GrADSVar
       for i in 0...@ctl.variables.length
         if @varname == @ctl.variables[i][:name]
           @attr[:long_name] = @ctl.variables[i][:description]
-          @attr[:nlev] = @ctl.variables[i][:nlev]
+          @attr[:nlev] = @ctl.variables[i][:nlev].to_s
         end
       end
     end
@@ -967,6 +974,7 @@ class GrADSVar
   alias ntype vartype
 
   def typecode
+    4
   end
 
   def natts
