@@ -393,7 +393,9 @@ These methods returns a NArray (not a VArray).
       end
       def set_att(name, val)
 	attr[name]=val
+	self
       end
+      alias put_att set_att
 
       def [](*slicer)
 	 mapping = SubsetMapping.new(self.shape_current, slicer)
@@ -448,7 +450,7 @@ These methods returns a NArray (not a VArray).
       # type1 methods: returns a VArray with the same shape
       # type2 methods: returns the result directly
       NArray_type1_methods = ["sort", "sort_index", 
-	    "floor","ceil","round"]  # "to_f","to_i" -- I don't like the names
+	    "floor","ceil","round","to_f","to_i","to_type"]
       NArray_type2_methods1 = ["all?","any?","none?","where","where2",
             "to_a", "to_string"]
       NArray_type2_methods2 = ["rank", "shape", "total","length"]
@@ -538,7 +540,7 @@ These methods returns a NArray (not a VArray).
 	 eval <<-EOS, nil, __FILE__, __LINE__+1
 	 def #{f}(*args)
             result = self.val.#{f}(*args)
-            if result.is_a?(NArray)
+            if result.is_a?(NArray) || result.is_a?(NArrayMiss)
 	       VArray.new(result , self.attr.copy, self.name )
             else
 	       result
@@ -612,10 +614,10 @@ if $0 == __FILE__
    p "eq",vc.eq(vt),vc.equal?(vt)
 
    vd = VArray.new( NArray.int(6).indgen!+10 )
-   p "+++",vd[1].val
+   p "+++",vd[1],vd[1].rank,vd[1].val
    p va.val
    p vs
    p va.sort.val
-   p vs.to_a, vs.to_string
+   p vs.to_a, vs.to_string, vs.to_f, vs.to_type(NArray::SINT)
    p "@@@",va.max, va.max(0), va.max(0,1)
 end
